javacommons/javastorage/tsrc/java_api/javasrc/com/nokia/mj/impl/storage/TestStorageAttribute.java
branchRCL_3
changeset 83 26b2b12093af
parent 71 d5e927d5853b
--- a/javacommons/javastorage/tsrc/java_api/javasrc/com/nokia/mj/impl/storage/TestStorageAttribute.java	Wed Sep 15 12:05:25 2010 +0300
+++ b/javacommons/javastorage/tsrc/java_api/javasrc/com/nokia/mj/impl/storage/TestStorageAttribute.java	Wed Oct 13 14:23:59 2010 +0300
@@ -136,10 +136,10 @@
      * 2. Test with Name and Value.
      * 3. Test Name null throws StorageException
      * 4. Test Name "" throws StorageException
      * 5. Test value null. It is allowed value.
      * 6. Test value "".
      * 7. Test one len name and value.
-     * 8. Test value null, type STRING is allowed.
+     * 8. Test value null, type STRING throws StorageException.
      */
     public void testNameValueConstructor()
     {
@@ -195,10 +195,11 @@
             String name = "AttrName";
             String value = null;
             sa = new StorageAttribute(name, value);
+            assertTrue("No exp when value Null", false);
         }
         catch (StorageException se)
         {
-            assertTrue("SE thrown when null value: " + se.toString(), false);
+            // PASSED
         }
         catch (Throwable t)
         {
@@ -245,10 +246,11 @@
             String name = "A";
             String value = null;
             sa = new StorageAttribute(name, value);
+            assertTrue("No exp thrown when null value, string type", false);
         }
         catch (StorageException se)
         {
-            assertTrue("SE thrown when null value: " + se.toString(), false);
+            // PASSED
         }
         catch (Throwable t)
         {
@@ -136,10 +136,10 @@
      * 3. Test Name null throws StorageException
      * 4. Test Name "" throws StorageException
-     * 5. Test value null. It is allowed value.
+     * 5. Test value null. Type is not set SE thrown.
      * 6. Test value "".
      * 7. Test one len name and value.